

<html xmlns:py="http://genshi.edgewall.org/" xmlns:xi="http://www.w3.org/2001/XInclude">
	<xi:include href="../layout.html" />
	<head>
		<title>Statistics</title>
		<link rel="stylesheet" type="text/css" href="/data/manager.css" />
	</head>
	<body id="hours-manager">
		<navheader>/manager/statistics</navheader>
		<h2>Statistics</h2>
		<ul>
			<li><strong>Sessions Today</strong>: $result.sessions_for_day</li>
			<li><strong>Sessions This Week</strong>: $result.sessions_for_week</li>
			<li><strong>Sessions This Month</strong>: $result.sessions_for_month</li>
			<li><strong>Sessions This Year</strong>: $result.sessions_for_year</li>
			<li><strong>Total Number of Sessions</strong>: $result.sessions</li>
			<li><strong>Registered Users</strong>: $result.registered_users</li>
		</ul>
	</body>
</html>
