@import url("reset.css");
body {
	margin: 0pt;
	padding: 0pt;
	font-family: sans-serif;
}
ul, ol {
	padding-left: 40px;
}

ol li {
	list-style-type: decimal;
}

ul li {
	list-style-type: disc;
}

li {
	padding-top: 5px;
}

p, table {
	margin: 5px;
}

h2 {
	padding: 5px;
	text-align: center;
	font-size: 20px;
}

form, button {
	font-size: 15px;
}

button {
	font-weight: bold;
}

button[disabled] {
	background-color: #444;
	border-color: #222;
	padding: 0 6px;
}

input, select {
	font-size: 15px;
	width: 10em;
}

input[type=checkbox] {
	width: auto;
}

label {
	display: -moz-inline-box;
	display: inline-block;
	width: 8em;
}

th {
	padding: 5px;
}

#header h1 {
	text-align: center;
	margin: 0pt;
	padding: 10px;
	font-size: 25px;
}
#reserve-form {
	margin-left: auto;
	margin-right: auto;
	padding: 15px;
	padding-bottom: 30px;
	text-align: center;
}
#content {
	padding: 15px;
}
#reserve-form label {
	font-weight: bold;
	padding-right: 0.75em;
	width: auto;
}
#reserve-form * {
	font-size: 25px;
	position: relative;
}
#reserve-form input {
	width: 300px;
}
#reserve-form button, #reserve-form input {
	font-size: 20px;
}
#sessions {
	margin-left: auto;
	margin-right: auto;
	text-align: center;
	width: 300px;
}
#sessions ul {
	margin: 5px;
	text-align: left;
}
#sessions li {
	height: 35px;
	line-height: 35px;
	vertical-align: middle;
}
#sessions .logged-on {
	list-style-image: url(/data/images/on.png);
}
#sessions .waiting {
	list-style-image: url(/data/images/waiting.png);
}
.navbar {
	display: block;
	position: absolute;
	top: 15px;
	right: 5px;
}
.navbar li {
	display: inline;
}

table {
	margin-left: auto;
	margin-right: auto;
}

#wrapper div { 
	float: left;
	width: 48%;
	margin-left: 15px;
}
/* we need this for IE 5.01 - otherwise the wrapper does not expand to the
necessary height (unless fixed, this problem becomes even more acute 
weirdness as the method is enhanced */
#wrapper {
/* Normally a Holly-style hack height: 1% would suffice but that causes 
IE 5.01 to completely collapse the wrapper - instead we float it */
	float: left;
/* NB. possibly only IE 5.01 needs to get this float value - otherwise 5.5 sometimes 
(I saw it happen many moons ago) makes the width of wrapper too small 
the float: none with the comment is ignored by 5.01,
5.5 and above see it and carry on about their business
It's probably fine to just remove it, but it's left here 
just in case that many moons ago problem rears its head again */
	float/**/: none;
	}
/* easy clearing */
#wrapper:after {
	content: '[DO NOT LEAVE IT IS NOT REAL]'; 
	display: block; 
	height: 0; 
	clear: both; 
	visibility: hidden;
}
#wrapper {
	display: inline-block;
}
/*\*/
#wrapper {
	display: block;
}
