

<html xmlns:py="http://genshi.edgewall.org/" xmlns:xi="http://www.w3.org/2001/XInclude">
	<xi:include href="../layout.html" />
	<head>
		<title>Manage Users - Search for $query</title>
		<link rel="stylesheet" type="text/css" href="/data/manager.css" />
	</head>
	<body id="user-search">
		<navheader>/manager/users/search</navheader>
		<h2>Search Results for "$query"</h2>
		<?python from datetime import date ?>
		<message py:if="not result">No results</message>
		<ul id="users" py:if="result">
			<li py:for="user in result"><a href="/manager/users/$user.username">$user.username</a><py:if test="user.allowed_after >= date.today()"> - banned</py:if></li>
		</ul>
	</body>
</html>
