<html xmlns:py="http://genshi.edgewall.org/" xmlns:xi="http://www.w3.org/2001/XInclude">
	<xi:include href="../layout.html" />
	<head>
		<title>Manage Users</title>
		<link rel="stylesheet" type="text/css" href="/data/manager.css" />
	</head>
	<body id="users-manager">
		<navheader>/manager/users/</navheader>
		<h2>Find a User</h2>
		<form id="find-user" action="search" method="GET">
			<input name="query" id="query" /><button type="submit">Search</button>
		</form>
		<h2>Create a User</h2>
		<form id="create-user" action="" method="POST">
			<label for="username">Username: </label><input name="username" id="username" /><button type="submit">Create</button>
		</form>
		<h2><a href="search?query=">User Listing</a></h2>
	</body>
</html>
