<html xmlns:py="http://genshi.edgewall.org/" xmlns:xi="http://www.w3.org/2001/XInclude">
	<xi:include href="../layout.html" />
	<head>
		<title>Login</title>
		<link rel="stylesheet" type="text/css" href="/data/manager.css" />
	</head>
	<body id="login">
		<navheader>/manager/login</navheader>
		<h2>Log In</h2>
		<form action="" method="POST">
			<input name="original_page" type="hidden" value="$original_page" />
			<p><label for="username">Username: </label><input name="username" value="$username" /></p>
			<p><label for="password">Password: </label><input name="password" type="password" /></p>
			<p><button type="submit">Submit</button></p>
		</form>
	</body>
</html>
